@@ -18,35 +18,33 @@
 
 #include "config.h"
 
-#include <vicious.h>
-#include "gdm.h"
-#include "misc.h"
-#include "getvt.h"
-
 #include <stdio.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <string.h>
 #include <fcntl.h>
 #include <dirent.h>
+#include <errno.h>
 #include <sys/ioctl.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 
-extern int GdmFirstVT;
-extern gboolean GdmVTAllocation;
+#include "gdm.h"
+#include "misc.h"
+#include "getvt.h"
+#include "gdmconfig.h"
 
 /* Virtual terminals only supported on Linux, FreeBSD, or DragonFly */
 
 #if defined (__linux__) || defined (__FreeBSD__) || defined (__DragonFly__)
 
-#ifdef __linux__
+#if defined (__linux__)
 #include <sys/vt.h>
-#elif defined(__FreeBSD__) || defined(__DragonFly__)
+#elif defined (__FreeBSD__) || defined (__DragonFly__)
 #include <sys/consio.h>
 
 static const char*
-__itovty(int val)
+__itovty (int val)
 {
 	static char str[8];
 	char* next = str + sizeof (str) - 1;
@@ -68,8 +66,8 @@ open_vt (int vtno)
 
 #if defined (__linux__)
 	vtname = g_strdup_printf ("/dev/tty%d", vtno);
-#elif defined (__FreeBSD__) || defined(__DragonFly__)
-	vtname = g_strdup_printf ("/dev/ttyv%s", __itovty(vtno - 1));
+#elif defined (__FreeBSD__) || defined (__DragonFly__)
+	vtname = g_strdup_printf ("/dev/ttyv%s", __itovty (vtno - 1));
 #endif
 	do {
 		errno = 0;
@@ -111,7 +109,7 @@ get_free_vt_linux (int *vtfd)
 		return -1;
 	}
 
-	for (vtno = GdmFirstVT, vtmask = 1 << vtno;
+	for (vtno = gdm_get_value_int (GDM_KEY_FIRST_VT), vtmask = 1 << vtno;
 			vtstat.v_state & vtmask; vtno++, vtmask <<= 1);
 	if (!vtmask) {
 		VE_IGNORE_EINTR (close (fd));
@@ -127,7 +125,7 @@ get_free_vt_linux (int *vtfd)
 	return vtno;
 }
 
-#elif defined (__FreeBSD__) || defined(__DragonFly__)
+#elif defined (__FreeBSD__) || defined (__DragonFly__)
 
 static int
 get_free_vt_freebsd_dragonfly (int *vtfd)
@@ -149,7 +147,7 @@ get_free_vt_freebsd_dragonfly (int *vtfd)
 	if (fd < 0)
 		return -1;
 
-	if ((ioctl(fd, VT_OPENQRY, &vtno) < 0) || (vtno == -1)) {
+	if ((ioctl (fd, VT_OPENQRY, &vtno) < 0) || (vtno == -1)) {
 		VE_IGNORE_EINTR (close (fd));
 		return -1;
 	}
@@ -160,12 +158,12 @@ get_free_vt_freebsd_dragonfly (int *vtfd)
 		return -1;
 	}
 
-	while (vtno < GdmFirstVT) {
+	while (vtno < gdm_get_value_int (GDM_KEY_FIRST_VT)) {
 		int oldvt = vtno;
 		to_close_vts = g_list_prepend (to_close_vts,
 					       GINT_TO_POINTER (fdv));
 
-		if (ioctl(fd, VT_OPENQRY, &vtno) == -1) {
+		if (ioctl (fd, VT_OPENQRY, &vtno) == -1) {
 			vtno = -1;
 			goto cleanup;
 		}
@@ -196,14 +194,14 @@ cleanup:
 char *
 gdm_get_empty_vt_argument (int *fd, int *vt)
 {
-	if ( ! GdmVTAllocation) {
+	if ( ! gdm_get_value_bool (GDM_KEY_VT_ALLOCATION)) {
 		*fd = -1;
 		return NULL;
 	}
 
-#if defined(__linux__)
+#if defined (__linux__)
 	*vt = get_free_vt_linux (fd);
-#elif defined(__FreeBSD__) || defined(__DragonFly__)
+#elif defined (__FreeBSD__) || defined (__DragonFly__)
 	*vt = get_free_vt_freebsd_dragonfly (fd);
 #endif
 
@@ -243,7 +241,7 @@ gdm_get_cur_vt (void)
 {
 #if defined (__linux__)
 	struct vt_stat s;
-#elif defined (__FreeBSD__) || defined(__DragonFly__)
+#elif defined (__FreeBSD__) || defined (__DragonFly__)
 	int vtno;
 #endif
 	int fd;
@@ -269,7 +267,7 @@ gdm_get_cur_vt (void)
 	*/
 
 	return s.v_active;
-#elif defined (__FreeBSD__) || defined(__DragonFly__)
+#elif defined (__FreeBSD__) || defined (__DragonFly__)
 	if (ioctl (fd, VT_GETACTIVE, &vtno) == -1) {
 		VE_IGNORE_EINTR (close (fd));
 		return -1;
