@@ -114,7 +114,6 @@ parse_id (xmlNodePtr node,
     }
 }
 
-
 /* Doesn't set the parts of rect that are not specified.
  * If you want specific default values you need to fill them out
  * in rect first
@@ -302,6 +301,251 @@ parse_pos (xmlNodePtr       node,
   return TRUE;
 }
 
+/* We pass the same arguments as to translated text, since we'll override it
+ * with translation score */
+static gboolean
+parse_stock (xmlNodePtr node,
+	     GreeterItemInfo *info,
+	     char     **translated_text,
+	     gint      *translation_score,
+	     GError   **error)
+{
+  xmlChar *prop;
+  
+  prop = xmlGetProp (node,(const xmlChar *) "type");
+  if (prop)
+    {
+      if (g_ascii_strcasecmp ((char *) prop, "language") == 0)
+        {
+	  g_free (*translated_text);
+	  *translated_text = g_strdup (_("_Language"));
+	}
+      else if (g_ascii_strcasecmp ((char *) prop, "session") == 0)
+        {
+	  g_free (*translated_text);
+	  *translated_text = g_strdup (_("_Session"));
+	}
+      else if (g_ascii_strcasecmp ((char *) prop, "system") == 0)
+        {
+	  g_free (*translated_text);
+	  *translated_text = g_strdup (_("_Actions"));
+	}
+      else if (g_ascii_strcasecmp ((char *) prop, "disconnect") == 0)
+        {
+	  g_free (*translated_text);
+	  *translated_text = g_strdup (_("D_isconnect"));
+	}
+      else if (g_ascii_strcasecmp ((char *) prop, "quit") == 0)
+        {
+	  g_free (*translated_text);
+	  *translated_text = g_strdup (_("_Quit"));
+	}
+      else if (g_ascii_strcasecmp ((char *) prop, "halt") == 0)
+        {
+	  g_free (*translated_text);
+	  *translated_text = g_strdup (_("Shut _Down"));
+	}
+      else if (g_ascii_strcasecmp ((char *) prop, "suspend") == 0)
+        {
+	  g_free (*translated_text);
+	  *translated_text = g_strdup (_("Sus_pend"));
+	}
+      else if (g_ascii_strcasecmp ((char *) prop, "reboot") == 0)
+        {
+	  g_free (*translated_text);
+	  *translated_text = g_strdup (_("_Restart"));
+	}
+      else if (g_ascii_strcasecmp ((char *) prop, "chooser") == 0)
+        {
+	  g_free (*translated_text);
+	  *translated_text = g_strdup (_("Remote Login via _XDMCP"));
+	}
+      else if (g_ascii_strcasecmp ((char *) prop, "config") == 0)
+        {
+	  g_free (*translated_text);
+	  *translated_text = g_strdup (_("Confi_gure"));
+	}
+      else if (g_ascii_strcasecmp ((char *) prop, "options") == 0)
+        {
+	  g_free (*translated_text);
+	  *translated_text = g_strdup (_("Op_tions"));
+	}
+      else if (g_ascii_strcasecmp ((char *) prop, "caps-lock-warning") == 0)
+        {
+	  g_free (*translated_text);
+	  *translated_text = g_strdup (_("Caps Lock is on."));
+	}
+      else if (g_ascii_strcasecmp ((char *) prop, "timed-label") == 0)
+        {
+	  g_free (*translated_text);
+	  *translated_text = g_strdup (_("User %u will login in %t"));
+	}
+      else if (g_ascii_strcasecmp ((char *) prop, "welcome-label") == 0)
+        {
+	  /* FIXME: hack */
+	  welcome_string_info = info;
+
+	  g_free (*translated_text);
+	  *translated_text = gdm_common_get_welcomemsg ();
+	}
+      /* FIXME: is this actually needed? */
+      else if (g_ascii_strcasecmp ((char *) prop, "username-label") == 0)
+        {
+	  g_free (*translated_text);
+	  *translated_text = g_strdup (_("Username:"));
+	}
+      else if (g_ascii_strcasecmp ((char *) prop, "ok") == 0)
+        {
+	  g_free (*translated_text);
+	  *translated_text = g_strdup (_("_OK"));
+	}
+      else if (g_ascii_strcasecmp ((char *) prop, "cancel") == 0)
+        {
+	  g_free (*translated_text);
+	  *translated_text = g_strdup (_("_Cancel"));
+	}
+      else if (g_ascii_strcasecmp ((char *) prop, "startagain") == 0)
+        {
+          g_free (*translated_text);
+          *translated_text = g_strdup (_("_Start Again"));
+        }
+      else
+        {
+          g_set_error (error,
+		       GREETER_PARSER_ERROR,
+		       GREETER_PARSER_ERROR_BAD_SPEC,
+		       "Bad stock label type");
+	  xmlFree (prop);
+	  return FALSE;
+	}
+
+      /* This is the very very very best "translation" */
+      *translation_score = -1;
+
+      xmlFree (prop);
+
+      return TRUE;
+    }
+  else
+    {
+      g_set_error (error,
+		   GREETER_PARSER_ERROR,
+		   GREETER_PARSER_ERROR_BAD_SPEC,
+		   "Stock type not specified");
+      return FALSE;
+    }
+}
+
+static void
+do_font_size_reduction (GreeterItemInfo *info)
+{
+  double size_reduction = 1.0;
+  int i;
+
+  if (gdm_wm_screen.width <= 800 &&
+      gdm_wm_screen.width > 640)
+    size_reduction = PANGO_SCALE_SMALL;
+  else if (gdm_wm_screen.width <= 640)
+    size_reduction = PANGO_SCALE_X_SMALL;
+
+  if (size_reduction < 0.99)
+    {
+      for (i = 0; i < GREETER_ITEM_STATE_MAX; i++)
+        {
+          if (info->data.text.fonts[i] != NULL)
+	    {
+	      int old_size = pango_font_description_get_size (info->data.text.fonts[i]);
+	      pango_font_description_set_size (info->data.text.fonts[i], old_size * size_reduction);
+	    }
+	}
+    }
+}
+
+
+static gboolean
+parse_canvasbutton (xmlNodePtr node,
+		    GreeterItemInfo *info,
+		    GError **error)
+{
+  xmlChar *prop;
+  
+  prop = xmlGetProp (node,(const xmlChar *) "button");
+  if (prop)
+    {
+      if (strcmp ((char *) prop, "true") == 0)
+	{
+	  info->canvasbutton = TRUE;
+	}
+      else if (strcmp ((char *) prop, "false") == 0)
+	{
+	  info->canvasbutton = FALSE;
+	}
+      else
+	{
+	  g_set_error (error,
+		       GREETER_PARSER_ERROR,
+		       GREETER_PARSER_ERROR_BAD_SPEC,
+		       "bad button spec %s", prop);
+	  xmlFree (prop);
+	  return FALSE;
+	}
+      xmlFree (prop);
+    }
+  return TRUE;
+}
+
+static gboolean
+parse_gtkbutton (xmlNodePtr node,
+		    GreeterItemInfo *info,
+		    GError **error)
+{
+  xmlNodePtr child;
+  char *translated_text  = NULL;
+  gint translation_score = 1000;
+  int i;
+
+  child = node->children;
+
+  while (child)
+    {
+      if (strcmp ((char *) child->name, "pos") == 0)
+	{
+	  if G_UNLIKELY (!parse_pos (child, info, error))
+	    return FALSE;
+	}
+      else if (child->type == XML_ELEMENT_NODE &&
+	       strcmp ((char *) child->name, "stock") == 0)
+	{
+	  if G_UNLIKELY (!parse_stock (child, info, &translated_text, &translation_score, error))
+	    return FALSE;
+	}
+
+      child = child->next;
+    }
+
+  if (translated_text == NULL)
+    {
+      g_set_error (error,
+                   GREETER_PARSER_ERROR,
+                   GREETER_PARSER_ERROR_BAD_SPEC,
+                   "A label must specify the text attribute");
+      return FALSE;
+    }
+
+  /* FIXME: evil hack to use internally translated strings */
+  if (translation_score == 999 &&
+      ! ve_string_empty (translated_text))
+    {
+      char *foo = g_strdup (_(translated_text));
+      g_free (translated_text);
+      translated_text = foo;
+    }
+
+  info->data.text.orig_text = translated_text;
+
+  return TRUE;
+}
+
 static gboolean
 parse_show (xmlNodePtr       node,
 	    GreeterItemInfo *info,
@@ -1000,249 +1244,6 @@ parse_translated_text (xmlNodePtr node,
   return TRUE;
 }
 
-/* We pass the same arguments as to translated text, since we'll override it
- * with translation score */
-static gboolean
-parse_stock (xmlNodePtr node,
-	     GreeterItemInfo *info,
-	     char     **translated_text,
-	     gint      *translation_score,
-	     GError   **error)
-{
-  xmlChar *prop;
-  
-  prop = xmlGetProp (node,(const xmlChar *) "type");
-  if (prop)
-    {
-      if (g_ascii_strcasecmp ((char *) prop, "language") == 0)
-        {
-	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("_Language"));
-	}
-      else if (g_ascii_strcasecmp ((char *) prop, "session") == 0)
-        {
-	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("_Session"));
-	}
-      else if (g_ascii_strcasecmp ((char *) prop, "system") == 0)
-        {
-	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("_Actions"));
-	}
-      else if (g_ascii_strcasecmp ((char *) prop, "disconnect") == 0)
-        {
-	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("D_isconnect"));
-	}
-      else if (g_ascii_strcasecmp ((char *) prop, "quit") == 0)
-        {
-	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("_Quit"));
-	}
-      else if (g_ascii_strcasecmp ((char *) prop, "halt") == 0)
-        {
-	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("Shut _Down"));
-	}
-      else if (g_ascii_strcasecmp ((char *) prop, "suspend") == 0)
-        {
-	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("Sus_pend"));
-	}
-      else if (g_ascii_strcasecmp ((char *) prop, "reboot") == 0)
-        {
-	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("_Restart"));
-	}
-      else if (g_ascii_strcasecmp ((char *) prop, "chooser") == 0)
-        {
-	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("Remote Login via _XDMCP"));
-	}
-      else if (g_ascii_strcasecmp ((char *) prop, "config") == 0)
-        {
-	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("Confi_gure"));
-	}
-      else if (g_ascii_strcasecmp ((char *) prop, "options") == 0)
-        {
-	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("Op_tions"));
-	}
-      else if (g_ascii_strcasecmp ((char *) prop, "caps-lock-warning") == 0)
-        {
-	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("Caps Lock is on."));
-	}
-      else if (g_ascii_strcasecmp ((char *) prop, "timed-label") == 0)
-        {
-	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("User %u will login in %t"));
-	}
-      else if (g_ascii_strcasecmp ((char *) prop, "welcome-label") == 0)
-        {
-	  /* FIXME: hack */
-	  welcome_string_info = info;
-
-	  g_free (*translated_text);
-	  *translated_text = gdm_common_get_welcomemsg ();
-	}
-      /* FIXME: is this actually needed? */
-      else if (g_ascii_strcasecmp ((char *) prop, "username-label") == 0)
-        {
-	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("Username:"));
-	}
-      else if (g_ascii_strcasecmp ((char *) prop, "ok") == 0)
-        {
-	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("_OK"));
-	}
-      /*
-       * Support startagain as cancel for forward compatibility without
-       * string breakage.
-       */
-      else if (g_ascii_strcasecmp ((char *) prop, "cancel") == 0 ||
-               g_ascii_strcasecmp ((char *) prop, "startagain") == 0)
-        {
-	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("_Cancel"));
-	}
-      else
-        {
-          g_set_error (error,
-		       GREETER_PARSER_ERROR,
-		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "Bad stock label type");
-	  xmlFree (prop);
-	  return FALSE;
-	}
-
-      /* This is the very very very best "translation" */
-      *translation_score = -1;
-
-      xmlFree (prop);
-
-      return TRUE;
-    }
-  else
-    {
-      g_set_error (error,
-		   GREETER_PARSER_ERROR,
-		   GREETER_PARSER_ERROR_BAD_SPEC,
-		   "Stock type not specified");
-      return FALSE;
-    }
-}
-
-static void
-do_font_size_reduction (GreeterItemInfo *info)
-{
-  double size_reduction = 1.0;
-  int i;
-
-  if (gdm_wm_screen.width <= 800 &&
-      gdm_wm_screen.width > 640)
-    size_reduction = PANGO_SCALE_SMALL;
-  else if (gdm_wm_screen.width <= 640)
-    size_reduction = PANGO_SCALE_X_SMALL;
-
-  if (size_reduction < 0.99)
-    {
-      for (i = 0; i < GREETER_ITEM_STATE_MAX; i++)
-        {
-          if (info->data.text.fonts[i] != NULL)
-	    {
-	      int old_size = pango_font_description_get_size (info->data.text.fonts[i]);
-	      pango_font_description_set_size (info->data.text.fonts[i], old_size * size_reduction);
-	    }
-	}
-    }
-}
-
-static gboolean
-parse_canvasbutton (xmlNodePtr node,
-		    GreeterItemInfo *info,
-		    GError **error)
-{
-  xmlChar *prop;
-  
-  prop = xmlGetProp (node,(const xmlChar *) "button");
-  if (prop)
-    {
-      if (strcmp ((char *) prop, "true") == 0)
-	{
-	  info->canvasbutton = TRUE;
-	}
-      else if (strcmp ((char *) prop, "false") == 0)
-	{
-	  info->canvasbutton = FALSE;
-	}
-      else
-	{
-	  g_set_error (error,
-		       GREETER_PARSER_ERROR,
-		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "bad button spec %s", prop);
-	  xmlFree (prop);
-	  return FALSE;
-	}
-      xmlFree (prop);
-    }
-  return TRUE;
-}
-
-static gboolean
-parse_gtkbutton (xmlNodePtr node,
-		    GreeterItemInfo *info,
-		    GError **error)
-{
-  xmlNodePtr child;
-  char *translated_text  = NULL;
-  gint translation_score = 1000;
-
-  child = node->children;
-
-  while (child)
-    {
-      if (strcmp ((char *) child->name, "pos") == 0)
-	{
-	  if G_UNLIKELY (!parse_pos (child, info, error))
-	    return FALSE;
-	}
-      else if (child->type == XML_ELEMENT_NODE &&
-	       strcmp ((char *) child->name, "stock") == 0)
-	{
-	  if G_UNLIKELY (!parse_stock (child, info, &translated_text, &translation_score, error))
-	    return FALSE;
-	}
-
-      child = child->next;
-    }
-
-  if (translated_text == NULL)
-    {
-      g_set_error (error,
-                   GREETER_PARSER_ERROR,
-                   GREETER_PARSER_ERROR_BAD_SPEC,
-                   "A label must specify the text attribute");
-      return FALSE;
-    }
-
-  /* FIXME: evil hack to use internally translated strings */
-  if (translation_score == 999 &&
-      ! ve_string_empty (translated_text))
-    {
-      char *foo = g_strdup (_(translated_text));
-      g_free (translated_text);
-      translated_text = foo;
-    }
-
-  info->data.text.orig_text = translated_text;
-
-  return TRUE;
-}
-
 static gboolean
 parse_label_pos_extras (xmlNodePtr       node,
 			GreeterItemInfo *info,
@@ -1774,10 +1775,8 @@ greeter_parse (const char *file, const char *datadir,
 
   /* Now we can whack the hash, we don't want to keep cached
      pixbufs around anymore */
-  if (pixbuf_hash != NULL) {
-     g_hash_table_destroy (pixbuf_hash);
-     pixbuf_hash = NULL;
-  }
+  g_hash_table_destroy (pixbuf_hash);
+  pixbuf_hash = NULL;
 
   if G_UNLIKELY (!res)
     {
